@@ -119,17 +119,15 @@ get_parameters.BFBayesFactor <- function(x,
 
   # check if valid model was indexed...
 
-  if (length(x@numerator) > 1 ||
+  if ((length(x@numerator) > 1 ||
     !xor(
       x@denominator@shortName == "Intercept only",
       grepl("^(Null|Indep)", x@denominator@shortName)
-    )) {
-    if (verbose) {
-      message(
-        "Multiple `BFBayesFactor` models detected - posteriors are extracted from the first numerator model.\n",
-        'See help("get_parameters", package = "insight").'
-      )
-    }
+    )) && verbose) {
+    format_alert(
+      "Multiple `BFBayesFactor` models detected - posteriors are extracted from the first numerator model.",
+      'See help("get_parameters", package = "insight").'
+    )
   }
 
 
@@ -195,7 +193,7 @@ get_parameters.stanmvreg <- function(x,
 
   for (i in names(parms)) {
     parms[[i]]$conditional <- sprintf("%s|%s", i, parms[[i]]$conditional)
-    find_bracket <- regexpr(pattern = "\\[", parms[[i]]$random)
+    find_bracket <- regexpr(pattern = "[", parms[[i]]$random, fixed = TRUE)
     parms[[i]]$random <- paste0(
       substr(parms[[i]]$random, start = 1, stop = find_bracket),
       i, "|",
@@ -204,7 +202,7 @@ get_parameters.stanmvreg <- function(x,
     parms[[i]]$sigma <- NULL
   }
 
-  out <- as.data.frame(x)[unlist(lapply(compact_list(parms), function(i) i[elements]))]
+  out <- as.data.frame(x)[unlist(lapply(compact_list(parms), function(i) i[elements]), use.names = FALSE)]
 
   if (isTRUE(summary)) {
     out <- .summary_of_posteriors(out, centrality = centrality)
@@ -224,12 +222,12 @@ get_parameters.brmsfit <- function(x,
                                    centrality = "mean",
                                    ...) {
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
-  component <- match.arg(component, choices = c("all", .all_elements()))
+  component <- match.arg(component, choices = c("all", .all_elements(), "location", "distributional"))
 
   if (is_multivariate(x)) {
     parms <- find_parameters(x, flatten = FALSE, parameters = parameters)
     elements <- .get_elements(effects, component)
-    out <- as.data.frame(x)[unlist(lapply(parms, function(i) i[elements]))]
+    out <- as.data.frame(x)[unlist(lapply(parms, function(i) i[elements]), use.names = FALSE)]
   } else {
     out <- as.data.frame(x)[.get_parms_data(x, effects, component, parameters)]
   }
@@ -354,7 +352,7 @@ get_parameters.bamlss <- function(x,
   elements <- .get_elements(effects = "all", component)
 
   parms <- find_parameters(x, flatten = FALSE, parameters = parameters)
-  out <- as.data.frame(unclass(x$samples))[unname(unlist(parms[elements]))]
+  out <- as.data.frame(unclass(x$samples))[unlist(parms[elements], use.names = FALSE)]
   if (isTRUE(summary)) {
     out <- .summary_of_posteriors(out, centrality = centrality)
   }
@@ -460,9 +458,9 @@ get_parameters.sim <- function(x,
 
 .summary_of_posteriors <- function(out, centrality = "mean", ...) {
   s <- switch(centrality,
-    "mean" = sapply(out, mean, na.rm = TRUE),
-    "median" = sapply(out, stats::median, na.rm = TRUE),
-    sapply(out, mean, na.rm = TRUE)
+    "mean" = vapply(out, mean, numeric(1), na.rm = TRUE),
+    "median" = vapply(out, stats::median, numeric(1), na.rm = TRUE),
+    vapply(out, mean, numeric(1), na.rm = TRUE)
   )
   data.frame(
     Parameter = names(s),
@@ -548,7 +546,7 @@ get_parameters.sim <- function(x,
     }
   } else if (methods::is(object, "var_estimate")) {
     if (!methods::is(object, "default")) {
-      stop("Object must be from 'var_estimate'.", call. = FALSE)
+      format_error("Object must be from 'var_estimate'.")
     }
     p <- object$p
     pcors_total <- p * (p - 1) * 0.5
@@ -588,7 +586,7 @@ get_parameters.sim <- function(x,
     }
     posterior_samples <- cbind(posterior_samples, beta_start)
   } else {
-    stop("Object class not currently supported.", call. = FALSE)
+    format_error("Object class not currently supported.")
   }
 
   posterior_samples
