@@ -38,6 +38,6 @@ has_intercept <- function(x, verbose = TRUE) {
     intercept <- as.vector(attr(f_terms, "intercept"))
     return(intercept == 1)
   } else if (verbose) {
-    warning(format_message("Cannot extract terms from model formula."), call. = FALSE)
+    format_warning("Cannot extract terms from model formula.")
   }
 }
