@@ -92,14 +92,14 @@ supported_models <- function() {
     "multinom", "mvord", "mmclogit", "mmrm", "mmrm_fit", "mmrm_tmb",
 
     # n ----------------------------
-    "negbinmfx", "negbinirr",
+    "negbinmfx", "negbinirr", "nestedLogit",
 
     # o ----------------------------
     "ols", "onesampb", "orm",
 
     # p ----------------------------
     "PMCMR", "poissonmfx", "poissonirr", "pgmm", "plm", "polr", "psm",
-    "probitmfx",
+    "probitmfx", "phyloglm", "phylolm",
 
     # r ----------------------------
     "Rchoice", "ridgelm", "riskRegression", "rjags", "rlm", "rlmerMod",
